"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GameDataSetTasksEvent = void 0;
const events_1 = require("@skeldjs/events");
const misc_1 = require("../../misc");
/**
 * Emitted when a player's tasks are set.
 */
class GameDataSetTasksEvent extends events_1.BasicEvent {
    constructor(room, gamedata, 
    /**
     * Information about the player that had their tasks set.
     */
    player, 
    /**
     * The player's old tasks.
     */
    oldTasks, 
    /**
     * The player's new tasks that were just set.
     */
    newTasks) {
        super();
        this.room = room;
        this.gamedata = gamedata;
        this.player = player;
        this.oldTasks = oldTasks;
        this.newTasks = newTasks;
        this.eventName = "gamedata.settasks";
        this._alteredTasks = newTasks;
    }
    /**
     * The alternate tasks to set the player, if changed.
     */
    get alteredTasks() {
        return this._alteredTasks;
    }
    /**
     * Set the tasks to the tasks that the player had before this event.
     */
    revert() {
        this._alteredTasks = this.oldTasks;
    }
    /**
     * Change the tasks of the player that were set.
     * @param tasks Each {@link TaskType} to set the player.
     */
    setTasks(tasks) {
        this._alteredTasks = tasks.map(task => new misc_1.TaskState(task, false));
    }
}
exports.GameDataSetTasksEvent = GameDataSetTasksEvent;
GameDataSetTasksEvent.eventName = "gamedata.settasks";
//# sourceMappingURL=SetTasks.js.map