import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { HqHudEvent } from "./HqHudEvent";
import { Hostable } from "../../Hostable";
import { HqHudSystem } from "../../systems";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player completes a console while communications is sabotaged on Mira HQ.
 */
export declare class HqHudConsoleCompleteEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, HqHudEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly hqhudsystem: HqHudSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that completed the console. Only availabe if the client
     * is the host.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The ID of the console that was completed.
     */
    readonly consoleId: number;
    static eventName: "hqhud.consoles.complete";
    eventName: "hqhud.consoles.complete";
    private _alteredConsoleId;
    constructor(room: RoomType, hqhudsystem: HqHudSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that completed the console. Only availabe if the client
     * is the host.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The ID of the console that was completed.
     */
    consoleId: number);
    /**
     * The ID of the alternate console that will be completed, if changed.
     */
    get alteredConsoleId(): number;
    /**
     * Change the ID of the console that was completed.
     * @param consoleId The ID of the console to complete.
     */
    setConsoleId(consoleId: number): void;
}
