import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { LifeSuppSystem } from "../../systems";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { O2Event } from "./O2Event";
/**
 * Emitted when a oxygen console is completed.
 */
export declare class O2ConsolesCompleteEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, O2Event, ProtocolEvent {
    readonly room: RoomType;
    readonly oxygen: LifeSuppSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that completed the console. Only available is the client is the host.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The ID of the console that was completed.
     */
    readonly consoleId: number;
    static eventName: "o2.consoles.complete";
    eventName: "o2.consoles.complete";
    private _alteredConsoleId;
    constructor(room: RoomType, oxygen: LifeSuppSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that completed the console. Only available is the client is the host.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The ID of the console that was completed.
     */
    consoleId: number);
    /**
     * The ID of the altered console that will be completed instead, if changed.
     */
    get alteredConsoleId(): number;
    /**
     * Change the console that was completed.
     * @param consoleId The ID of the console to complete.
     */
    setConsole(consoleId: number): void;
}
