"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerCheckProtectEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player (i.e. a guardian angel) is attempting to protect another
 * player, and is requesting the host to verify the attempt and actually protect
 * the player. Only admitted if the client is the host.
 *
 * This event is useful if you want to prevent a protect from actually happening,
 * before it happens. Therefore this event doesn't guarantee that the target is
 * actually dead, see {@link PlayerProtectEvent} to listen for that.
 */
class PlayerCheckProtectEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The other player that the player is attempting to protect.
     */
    target, 
    /**
     * Whether or not this protect would normally be considered valid and thus
     * the player be protected.
     */
    isValid) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.target = target;
        this.isValid = isValid;
        this.eventName = "player.checkprotect";
        this._alteredPlayer = player;
        this._alteredTarget = target;
        this._alteredIsValid = isValid;
    }
    /**
     * The player that will protect the target instead, if altered.
     */
    get alteredPlayer() {
        return this._alteredPlayer;
    }
    /**
     * Change the player that will actually protect the target.
     */
    setPlayer(player) {
        this._alteredPlayer = player;
    }
    /**
     * The player that will protected instead, if altered.
     */
    get alteredTarget() {
        return this._alteredTarget;
    }
    /**
     * Change the player that will actually be protected.
     * @param target The player to protect.
     */
    setTarget(target) {
        this._alteredTarget = target;
    }
    /**
     * Whether or not this protect will be considered valid instead, if altered.
     */
    get alteredIsValid() {
        return this._alteredIsValid;
    }
    /**
     * Change whether this protect should be consider valid. If valid, ths player
     * will indeed be protected.
     * @param isValid Whether or not this protect should be considered valid.
     */
    setValid(isValid) {
        this._alteredIsValid = isValid;
    }
}
exports.PlayerCheckProtectEvent = PlayerCheckProtectEvent;
PlayerCheckProtectEvent.eventName = "player.checkprotect";
//# sourceMappingURL=CheckProtect.js.map