"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetImpostorsEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player (i.e. the host of the room) updates the impostor in the
 * room.
 */
class PlayerSetImpostorsEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The players that were made impostors.
     */
    impostors) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.impostors = impostors;
        this.eventName = "player.setimpostors";
        this._alteredImpostors = [...impostors];
        this._isDirty = false;
    }
    /**
     * The changed impostors that will be set instead, if changed.
     */
    get alteredImpostors() {
        return this._alteredImpostors;
    }
    /**
     * Whether the {@link PlayerSetImpostorsEvent.alteredImpostors} is different from
     * {@link PlayerSetImpostorsEvent.impostors}.
     */
    get isDirty() {
        return this._isDirty;
    }
    /**
     * Change the impostors that were set.
     * @param impostors The impostors to set.
     */
    setImpostors(impostors) {
        this._alteredImpostors = impostors;
        this._isDirty = true;
    }
}
exports.PlayerSetImpostorsEvent = PlayerSetImpostorsEvent;
PlayerSetImpostorsEvent.eventName = "player.setimpostors";
//# sourceMappingURL=SetImpostors.js.map