import { BasicEvent } from "@skeldjs/events";
import { SetPetMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player has their player pet updated.
 */
export declare class PlayerSetPetEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetPetMessage | undefined;
    /**
     * The pet that the player had before.
     */
    readonly oldPetId: string;
    /**
     * The new pet that the player has.
     */
    readonly newPetId: string;
    static eventName: "player.setpet";
    eventName: "player.setpet";
    private _alteredPetId;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetPetMessage | undefined, 
    /**
     * The pet that the player had before.
     */
    oldPetId: string, 
    /**
     * The new pet that the player has.
     */
    newPetId: string);
    /**
     * The altered pet that the player will have set instead, if changed.
     */
    get alteredPetId(): string;
    /**
     * Revert the player's pet back to their old pet.
     */
    revert(): void;
    /**
     * Change the pet that the player had set.
     * @param pet The pet to set.
     */
    setPet(pet: string): void;
}
