"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetRoleEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player role updated.
 */
class PlayerSetRoleEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The role that the player had before, if any.
     */
    oldRole, 
    /**
     * The new role that the player has, if any.
     */
    newRole) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldRole = oldRole;
        this.newRole = newRole;
        this.eventName = "player.setrole";
        this._alteredRole = newRole;
    }
    /**
     * The altered role that the player will have set instead, if changed.
     */
    get alteredRole() {
        return this._alteredRole;
    }
    /**
     * Revert the player's role back to their old role.
     */
    revert() {
        this.setRole(this.oldRole);
    }
    /**
     * Change the role that the player had set, or completely remove it altogether.
     * @param role The role to set.
     */
    setRole(roleCtr) {
        this._alteredRole = roleCtr;
    }
}
exports.PlayerSetRoleEvent = PlayerSetRoleEvent;
PlayerSetRoleEvent.eventName = "player.setrole";
//# sourceMappingURL=SetRole.js.map