"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerShapeshiftEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player (who is a shapeshifter) shapeshifts into another player.
 */
class PlayerShapeshiftEvent extends events_1.RevertableEvent {
    constructor(room, player, message, 
    /**
     * The target that the player shapeshifted into.
     */
    target, 
    /**
     * The duration, in seconds, for how long the player is shapeshifted for.
     */
    duration, 
    /**
     * Whether or not to show an animation of the player shapeshifting.
     */
    doAnimation) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.target = target;
        this.duration = duration;
        this.doAnimation = doAnimation;
        this.eventName = "player.shapeshift";
        this._alteredTarget = target;
        this._alteredDoAnimation = doAnimation;
    }
    /**
     * The player that the player will shapeshift into instead, if altered.
     */
    get alteredTarget() {
        return this._alteredTarget;
    }
    /**
     * Whether or not to show an animation of the player shapeshifting instead, if altered.
     */
    get alteredDoAnimation() {
        return this._alteredDoAnimation;
    }
    /**
     * Change the player that the player will shapeshift into.
     * @param target The player to shapeshift into instead.
     */
    setTarget(target) {
        this._alteredTarget = target;
    }
    /**
     * Change whether or not an animation will show the player shapeshifting.
     * @param doAnimation Whether or not to do show an animation of the player shape shifting.
     */
    setDoAnimation(doAnimation) {
        this._alteredDoAnimation = doAnimation;
    }
}
exports.PlayerShapeshiftEvent = PlayerShapeshiftEvent;
PlayerShapeshiftEvent.eventName = "player.shapeshift";
//# sourceMappingURL=Shapeshift.js.map