import { HazelReader, HazelWriter } from "@skeldjs/util";
import { BasicEvent, EventEmitter, ExtractEventTypes } from "@skeldjs/events";
import { AutoDoorsSystem, DoorsSystem, ElectricalDoorsSystem } from "../systems";
import { DoorsDoorCloseEvent, DoorsDoorOpenEvent } from "../events";
import { Hostable } from "../Hostable";
export declare type DoorEvents<RoomType extends Hostable = Hostable> = ExtractEventTypes<[
    DoorsDoorOpenEvent<RoomType>,
    DoorsDoorCloseEvent<RoomType>
]>;
/**
 * Represents a manual door for the {@link DoorsSystem} or {@link ElectricalDoorsSystem}.
 *
 * See {@link DoorEvents} for events to listen to.
 */
export declare class Door<RoomType extends Hostable = Hostable> extends EventEmitter<DoorEvents> {
    protected system: AutoDoorsSystem<RoomType> | DoorsSystem<RoomType> | ElectricalDoorsSystem<RoomType>;
    readonly doorId: number;
    isOpen: boolean;
    constructor(system: AutoDoorsSystem<RoomType> | DoorsSystem<RoomType> | ElectricalDoorsSystem<RoomType>, doorId: number, isOpen: boolean);
    emit<Event extends BasicEvent>(event: Event): Promise<Event>;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    setOpen(isOpen: boolean): Promise<void>;
    /**
     * Force the door open.
     */
    open(): Promise<void>;
    /**
     * Force the door to close.
     */
    close(): Promise<void>;
}
